============================================
The Alert Logic SDK for Python documentation
============================================

The Alert Logic SDK for Python enables developers to manage Alert Logic services.
It provides an easy to consume interface.

.. toctree::
   :maxdepth: 4

Quickstart
----------

.. toctree::
   :maxdepth: 2

   site/guides/quickstart
   site/guides/examples

API Reference
--------------

Services
~~~~~~~~~

.. toctree::
   :maxdepth: 3

   site/services/index

Core Modules
~~~~~~~~~~~~~
   modules

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
